@@ -27,6 +27,8 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
 
 #include "gdbmdefs.h"
 #include "gdbmerrno.h"
@@ -45,8 +47,8 @@ gdbm_delete (dbf, key)
   int home;		/* Home position of an item. */
   bucket_element elem;  /* The element to be deleted. */
   char *find_data;	/* Return pointer from findkey. */
-  word_t hash_val;	/* Returned by findkey. */
-  word_t free_adr;       /* Temporary stroage for address and size. */
+  int   hash_val;	/* Returned by findkey. */
+  off_t free_adr;       /* Temporary stroage for address and size. */
   int   free_size;
 
   /* First check to make sure this guy is a writer. */
