@@ -18,7 +18,7 @@
     the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
     You may contact the author by:
-       e-mail:  phil@wwu.edu
+       e-mail:  phil@cs.wwu.edu
       us-mail:  Philip A. Nelson
                 Computer Science Department
                 Western Washington University
@@ -27,28 +27,29 @@
 *************************************************************************/
 
 
-/* gdbm sends back the following error codes in the variable gdbm_errno. */
-typedef enum {	GDBM_NO_ERROR,
-		GDBM_MALLOC_ERROR,
-		GDBM_BLOCK_SIZE_ERROR,
-		GDBM_FILE_OPEN_ERROR,
-		GDBM_FILE_WRITE_ERROR,
-		GDBM_FILE_SEEK_ERROR,
-		GDBM_FILE_READ_ERROR,
-		GDBM_BAD_MAGIC_NUMBER,
-		GDBM_EMPTY_DATABASE,
-		GDBM_CANT_BE_READER,
-	        GDBM_CANT_BE_WRITER,
-		GDBM_READER_CANT_DELETE,
-		GDBM_READER_CANT_STORE,
-		GDBM_READER_CANT_REORGANIZE,
-		GDBM_UNKNOWN_UPDATE,
-		GDBM_ITEM_NOT_FOUND,
-		GDBM_REORGANIZE_FAILED,
-		GDBM_CANNOT_REPLACE,
-		GDBM_ILLEGAL_DATA,
-		GDBM_OPT_ALREADY_SET,
-		GDBM_OPT_ILLEGAL}
-	gdbm_error;
+/* gdbm sets the following error codes. */
+#define	GDBM_NO_ERROR		0
+#define	GDBM_MALLOC_ERROR	1
+#define	GDBM_BLOCK_SIZE_ERROR	2
+#define	GDBM_FILE_OPEN_ERROR	3
+#define	GDBM_FILE_WRITE_ERROR	4
+#define	GDBM_FILE_SEEK_ERROR	5
+#define	GDBM_FILE_READ_ERROR	6
+#define	GDBM_BAD_MAGIC_NUMBER	7
+#define	GDBM_EMPTY_DATABASE	8
+#define	GDBM_CANT_BE_READER	9
+#define	GDBM_CANT_BE_WRITER	10
+#define	GDBM_READER_CANT_DELETE	11
+#define	GDBM_READER_CANT_STORE	12
+#define	GDBM_READER_CANT_REORGANIZE	13
+#define	GDBM_UNKNOWN_UPDATE	14
+#define	GDBM_ITEM_NOT_FOUND	15
+#define	GDBM_REORGANIZE_FAILED	16
+#define	GDBM_CANNOT_REPLACE	17
+#define	GDBM_ILLEGAL_DATA	18
+#define	GDBM_OPT_ALREADY_SET	19
+#define	GDBM_OPT_ILLEGAL	29
+
+typedef int gdbm_error;		/* For compatibilities sake. */
 
 extern gdbm_error gdbm_errno;
