@@ -27,9 +27,12 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 
-static void write_header _ARGS((gdbm_file_info *));
+static void write_header __P((gdbm_file_info *));
 
 /* This procedure writes the header back to the file described by DBF. */
 
@@ -63,24 +66,27 @@ _gdbm_end_update (dbf)
   
   
   /* Write the current bucket. */
-  if (dbf->bucket_changed && (dbf->cache_entry != NULL)) {
+  if (dbf->bucket_changed && (dbf->cache_entry != NULL))
+    {
       _gdbm_write_bucket (dbf, dbf->cache_entry);
       dbf->bucket_changed = FALSE;
-  }
+    }
 
   /* Write the other changed buckets if there are any. */
-  if (dbf->second_changed) {
-    if(dbf->bucket_cache != NULL) {
-      register int index;
+  if (dbf->second_changed)
+    {
+      if(dbf->bucket_cache != NULL)
+        {
+          register int index;
 
-      for (index = 0; index < dbf->cache_size; index++) {
-	if (dbf->bucket_cache[index].ca_changed) {
-	    _gdbm_write_bucket (dbf, &dbf->bucket_cache[index]);
-	}
-      }
+          for (index = 0; index < dbf->cache_size; index++)
+	    {
+	      if (dbf->bucket_cache[index].ca_changed)
+	        _gdbm_write_bucket (dbf, &dbf->bucket_cache[index]);
+            }
+        }
+      dbf->second_changed = FALSE;
     }
-    dbf->second_changed = FALSE;
-  }
   
   /* Write the directory. */
   if (dbf->directory_changed)
@@ -106,14 +112,21 @@ _gdbm_end_update (dbf)
 
 /* If a fatal error is detected, come here and exit. VAL tells which fatal
    error occured. */
-int _gdbm_fatal (dbf, val)
+
+int
+_gdbm_fatal (dbf, val)
      gdbm_file_info *dbf;
      char *val;
 {
-  if (dbf->fatal_err != NULL)
+  if ((dbf != NULL) && (dbf->fatal_err != NULL))
     (*dbf->fatal_err) (val);
   else
-    fprintf (stderr, "gdbm fatal: %s.\n", val);
+    {
+      write (STDERR_FILENO, "gdbm fatal: ", 12);
+      if (val != NULL)
+	write (STDERR_FILENO, val, strlen(val));
+      write (STDERR_FILENO, "\n", 1);
+    }
   exit (-1);
   /* NOTREACHED */
 }
