@@ -26,5 +26,8 @@
        
 *************************************************************************/
 
+#include "autoconf.h"
+
 /* Keep a string with the version number in it! */
-char * gdbm_version = "This is GDBM version 1.7, as of November 3, 1993.";
+const char * gdbm_version =
+	"This is GDBM version 1.8.0, as of May 19, 1999.";
